% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PQB_IPCW_estimator.R
\name{PQB_IPCW_estimator}
\alias{PQB_IPCW_estimator}
\title{IPCW-Adjusted Proximal Weighting Estimation under Dependent Left Truncation and Random Right Censoring}
\usage{
PQB_IPCW_estimator(
  nu,
  t0,
  dat,
  time.name,
  Q.name,
  event.name = NULL,
  W1.name,
  W2.name,
  Z.name,
  weights = rep(1, nrow(dat)),
  trim.min = 1e-07,
  trim.max = 1e+07,
  IPCW_time_varying = FALSE,
  trim.IPCW = 1e-07
)
}
\arguments{
\item{nu}{A user-supplied transformation of the event time. For example,
\code{function(t) as.numeric(t > tau)} results in estimating a survival
probability beyond time \code{tau}.}

\item{t0}{A cutoff such that \code{nu(t) = nu(min(t, t0))}. For example, for
survival probability at time \code{tau}, one can set \code{t0 = tau}.}

\item{dat}{A data frame containing the observed data.}

\item{time.name}{Name of the observed event or censoring time variable.}

\item{Q.name}{Name of the left truncation time variable.}

\item{event.name}{Name of the event indicator variable. Set to \code{NULL} when
there is no right censoring.}

\item{W1.name}{Name of the truncation proxies.}

\item{W2.name}{Name of the event time proxies.}

\item{Z.name}{Name of the measured covariates that are directly associated with both the event time and the truncation time.}

\item{weights}{Optional nonnegative case weights. Defaults to equal weights.}

\item{trim.min}{Lower bound used to stabilize the estimated bridge weights.}

\item{trim.max}{Upper bound used to stabilize the estimated bridge weights.}

\item{IPCW_time_varying}{Logical; if \code{TRUE}, use time-varying IPCW weights in
the bridge estimation step.}

\item{trim.IPCW}{Lower bound used to stabilize the denominators of IPCW weights.}
}
\value{
A numeric scalar containing the IPCW-adjusted proximal weighting
estimator.
}
\description{
Computes the IPCW-adjusted proximal weighting estimator for the expectation
of an arbitrarily transformed event time under dependent left truncation
and random right censoring.
}
