% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/truncProxy-package.R
\docType{package}
\name{truncProxy-package}
\alias{truncProxy}
\alias{truncProxy-package}
\title{truncProxy: Proximal Weighting Estimation for Dependent Left Truncation}
\description{
Implements proximal weighting estimators for the expectation of an
arbitrarily transformed event time under dependent left truncation, with
optional inverse probability of censoring weighting to handle right
censoring. The methods leverage proxy variables to handle dependent left
truncation in settings where dependence-inducing factors are not fully
observed.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/wangyuyao98/truncProxy_weighting}
  \item \url{https://arxiv.org/pdf/2512.21283}
  \item Report bugs at \url{https://github.com/wangyuyao98/truncProxy_weighting/issues}
}

}
\author{
\strong{Maintainer}: Yuyao Wang \email{yuw079@ucsd.edu}

Authors:
\itemize{
  \item Andrew Ying
  \item Ronghui Xu
}

}
\keyword{internal}
