% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PQB_estimator.R
\name{PQB_estimator}
\alias{PQB_estimator}
\title{Proximal Weighting Estimation Under Dependent Left Truncation}
\usage{
PQB_estimator(
  nu,
  dat,
  time.name,
  Q.name,
  W1.name,
  W2.name,
  Z.name,
  weights = rep(1, nrow(dat)),
  trim.min = 1e-07,
  trim.max = 1e+07
)
}
\arguments{
\item{nu}{A user-supplied transformation of the event time. For example,
\code{function(t) as.numeric(t > tau)} results in estimating a survival
probability beyond time \code{tau}.}

\item{dat}{A data frame containing the observed data.}

\item{time.name}{Name of the event time variable.}

\item{Q.name}{Name of the left truncation time variable.}

\item{W1.name}{Name of the truncation proxies.}

\item{W2.name}{Name of the event time proxies.}

\item{Z.name}{Name of the measured covariates that are directly associated with both the event time and the truncation time.}

\item{weights}{Optional nonnegative case weights. Defaults to equal weights.}

\item{trim.min}{Lower bound used to stabilize the estimated bridge weights.}

\item{trim.max}{Upper bound used to stabilize the estimated bridge weights.}
}
\value{
A numeric scalar containing the proximal weighting estimator.
}
\description{
Computes the proximal weighting estimator for the expectation of an
arbitrarily transformed event time under dependent left truncation.
}
